@@ -140,13 +140,12 @@ def create_folders(project_name):
     create_main_folders('tester', 'main')
     create_main_folders('trainer', 'main')
     create_main_folders('server', 'main')
+    create_main_folders('test_scheme', 'server')
 
 def create_project(project_name):
     create_folders(project_name)
     project_name = clean_name(project_name)
     create_pipeline_file(project_name, directories['artifacts'], 'shared_artifacts')
-    create_pipeline_file(project_name, directories['schema'], 'inputs')
-    create_pipeline_file(project_name, directories['schema'], 'outputs')
     create_pipeline_file(project_name, directories['preprocessor'], 'preprocess')
     create_pipeline_file(project_name, directories['predictors'], 'predictor')
     create_pipeline_file(project_name, directories['forcers'], 'forcer')
@@ -154,6 +153,13 @@ def create_project(project_name):
     create_pipeline_file(project_name, directories['predictables'], 'predictable')
     create_pipeline_file(project_name, directories['pipeline'], 'pipeline')
     create_pipeline_file(project_name, directories['main'], 'test_pipeline', False)
+
+    create_scheme_file(project_name, directories['schema'], 'inputs')
+    create_scheme_file(project_name, directories['schema'], 'outputs')
+    create_scheme_file(project_name, directories['test_scheme'], 'test_input', False)
+    create_scheme_file(project_name, directories['test_scheme'], 'test_output', False)
+    create_scheme_file(project_name, directories['test_scheme'], '__init__', False)
+
     # create_tester_file(project_name, directories['tester'], 'tester')
     # create_tester_file(project_name, directories['tester'], 'reporter')
     create_server_file(project_name, directories['server'], 'main', False)
@@ -192,6 +198,9 @@ def create_pipeline_file(project_name, folder, pipelineType, createInitFile=True
     data = read_template_file(pipelineType)
     replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile)
 
+def create_scheme_file(project_name, folder, pipelineType, createInitFile=True):
+    data = read_template_file('scheme/' + pipelineType)
+    replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile)
 
 def create_server_file(project_name, folder, pipelineType, createInitFile=True):
     data = read_template_file('tester/server/' + pipelineType)
