@@ -2,9 +2,9 @@
 # coding: utf-8
 
 from typing import List, Any
-from dsFramework.base.common.component import ZIDS_Component
-from dsFramework.base.pipeline.predictables.predictable import ZIDS_Predictable
-from dsFramework.base.pipeline.artifacts.shared_artifacts import ZIDS_SharedArtifacts
+from dsframework.base.common.component import ZIDS_Component
+from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable
+from dsframework.base.pipeline.artifacts.shared_artifacts import ZIDS_SharedArtifacts
 
 class ZIDS_Preprocessor(ZIDS_Component):
 
